@@ -7,7 +7,7 @@ def fitness(p):
     return 0.5*x**3 - 4*(x+2)**2 + 3
 
 if __name__ == "__main__":
-    solver = pyfde.Solver(fitness, n_dim=1, n_pop=30, limits=(-5., 5.))
+    solver = pyfde.ClassicDE(fitness, n_dim=1, n_pop=30, limits=(-5., 5.), seed=50)
 
     # check for the stopping condition every 10 iterations
     last_best, last_fit, its = None, float("-inf"), 0
