@@ -8,7 +8,7 @@ def fitness(p):
     return -val
 
 if __name__ == "__main__":
-    solver = pyfde.Solver(fitness, n_dim=2, n_pop=40, limits=(-5.12, 512))
+    solver = pyfde.ClassicDE(fitness, n_dim=2, n_pop=40, limits=(-5.12, 512))
     solver.cr, solver.f = 0.9, 0.45
 
     best, fit = solver.run(n_it=150)
