@@ -9,7 +9,7 @@ def fitness(p):
     return sum
 
 if __name__ == "__main__":
-    solver = pyfde.Solver(fitness, n_dim=10, n_pop=50, limits=(-500., 500.))
+    solver = pyfde.ClassicDE(fitness, n_dim=10, n_pop=50, limits=(-500., 500.))
     solver.cr, solver.f = 0.5, 0.8
 
     best, fit = solver.run(n_it=1000)
